@@ -1,11 +1,11 @@
 colvm.mle <- function (x, tol = 1e-07) {
     n <- dim(x)[1]
-    C <- colmeans(cos(x))
-    S <- colmeans(sin(x))
+    C <- Rfast::colmeans( cos(x) )
+    S <- Rfast::colmeans( sin(x) )
     ep <- (C < 0)
     mu <- atan(S/C)
     mu[ep] <- mu[ep] + pi
-    con <- rowsums(cos(t(x) - mu))
+    con <- Rfast::rowsums(cos(t(x) - mu))
     R <- C^2 + S^2
     k1 <- (1.28 - 0.53 * R) * tan(0.5 * pi * sqrt(R))
     der <- con - n * besselI(k1, 1)/besselI(k1, 0)
