@@ -1,9 +1,4 @@
 correls <- function(y, x, type = "pearson", a = 0.05, rho = 0) {
-  ## y is a numerical vector
-  ## x is a matrix containing at least two variables
-  ## type supported is either "pearson" or "spearman"
-  ## a is the significance level
-  ## rho is the hypothesised correlation
   n <- length(y)
 
   if (type == "pearson") {
@@ -13,7 +8,7 @@ correls <- function(y, x, type = "pearson", a = 0.05, rho = 0) {
     se <- 1/sqrt(n - 3)  ## standard error for Fisher's transformation of Ho
 
   } else if (type == "spearman") {
-    r <- as.vector( cor(y, x, method = "spearman") ) ## the correlation value between y and all the xs
+    r <- as.vector( cor(Rfast::Rank(y), Rfast::colRanks(x) ) ) ## the correlation value between y and all the xs
     zh0 <- 0.5 * log( (1 + rho) / (1 - rho) )  ## Fisher's transformation for Ho
     zh1 <- 0.5 * log( (1 + r) / (1 - r) )  ## Fisher's transformation for H1
     se <- 1.029563 / sqrt(n - 3)  ## standard error for Fisher's transformation of Ho
