@@ -2,8 +2,10 @@
 #include <R_ext/Rdynload.h>
 
 
-SEXP Rfast_add_to_namespace(SEXP dir_to_exportSEXP,SEXP dir_to_fileSEXP,SEXP sortingSEXP);
+
+SEXP Rfast_add_to_namespace(SEXP dir_to_exportSEXP,SEXP dir_to_fileSEXP,SEXP sortingSEXP, SEXP no_readSEXP);
 SEXP Rfast_as_integer(SEXP x,SEXP sortedSEXP,SEXP initSEXP);
+SEXP Rfast_apply_condition(SEXP x,SEXP methodSEXP,SEXP operSEXP,SEXP valSEXP);
 SEXP Rfast_bcdcor(SEXP xSEXP,SEXP ySEXP);
 SEXP Rfast_binarysearch(SEXP xSEXP,SEXP vSEXP);
 SEXP Rfast_bic_fs_reg(SEXP ySEXP,SEXP dsSEXP,SEXP tolSEXP,SEXP typeSEXP);
@@ -11,6 +13,10 @@ SEXP Rfast_bs_reg(SEXP ySEXP,SEXP dsSEXP,SEXP sigSEXP,SEXP typeSEXP);
 SEXP Rfast_bincomb(SEXP xSEXP);
 SEXP Rfast_col_all(SEXP x);
 SEXP Rfast_col_count_values(SEXP xSEXP,SEXP valuesSEXP);
+SEXP Rfast_col_cum_maxs(SEXP x);
+SEXP Rfast_col_cum_sums(SEXP x);
+SEXP Rfast_col_cum_mins(SEXP x);
+SEXP Rfast_col_cum_prods(SEXP x);
 SEXP Rfast_col_meds(SEXP xSEXP,SEXP na_rmSEXP);
 SEXP Rfast_col_min_indices(SEXP xSEXP);
 SEXP Rfast_col_min(SEXP x);
@@ -30,11 +36,15 @@ SEXP Rfast_col_false(SEXP xSEXP);
 SEXP Rfast_col_order(SEXP xSEXP,SEXP stableSEXP,SEXP descendingSEXP);
 SEXP Rfast_col_pmax(SEXP x,SEXP y);
 SEXP Rfast_col_pmin(SEXP x,SEXP y);
-SEXP Rfast_col_prods(SEXP xSEXP);
+SEXP Rfast_col_prods(SEXP xSEXP,SEXP methodSEXP);
 SEXP Rfast_columns(SEXP x,SEXP ind);
+SEXP Rfast_chi2Test(SEXP dataSEXP,SEXP xSEXP,SEXP ySEXP,SEXP csSEXP,SEXP dcSEXP);
+SEXP Rfast_chi2Test_univariate(SEXP dataSEXP,SEXP dcSEXP);
+SEXP Rfast_chi2tests(SEXP dataSEXP,SEXP xSEXP,SEXP ySEXP,SEXP dcSEXP);
 SEXP Rfast_check_namespace(SEXP dir_to_exportSEXP,SEXP dir_to_fileSEXP);
 SEXP Rfast_check_aliases(SEXP dir_to_manSEXP,SEXP dir_to_fileSEXP);
 SEXP Rfast_check_true_false(SEXP path_manSEXP,SEXP no_readSEXP);
+SEXP Rfast_check_usage(SEXP path_manSEXP,SEXP path_rfSEXP,SEXP no_readSEXP);
 SEXP Rfast_col_any(SEXP x);
 SEXP Rfast_col_anovas(SEXP ySEXP,SEXP xSEXP);
 SEXP Rfast_cholesky(SEXP x);
@@ -42,7 +52,6 @@ SEXP Rfast_cholesky_par(SEXP x);
 SEXP Rfast_col_mads(SEXP x);
 SEXP Rfast_col_true_false(SEXP xSEXP);
 SEXP Rfast_count_value(SEXP xSEXP,SEXP valueSEXP);
-SEXP Rfast_count_na(SEXP x);
 SEXP Rfast_Choose(SEXP x,SEXP kSEXP);
 SEXP Rfast_dvar(SEXP xSEXP);
 SEXP Rfast_dcor(SEXP xSEXP,SEXP ySEXP);
@@ -87,6 +96,7 @@ SEXP Rfast_glm_poisson(SEXP xSEXP,SEXP ySEXP,SEXP ylogySEXP,SEXP tolSEXP);
 SEXP Rfast_hash2list(SEXP xSEXP,SEXP sortingSEXP);
 SEXP Rfast_hash_find(SEXP xSEXP,SEXP valueSEXP);
 SEXP Rfast_Hash_list(SEXP keySEXP,SEXP xSEXP);
+SEXP Rfast_Hash_key_multi(SEXP xSEXP,SEXP valueSEXP,SEXP sepSEXP);
 SEXP Rfast_is_element(SEXP xSEXP,SEXP elSEXP);
 SEXP Rfast_is_element_string(SEXP xSEXP,SEXP elSEXP);
 SEXP Rfast_is_integer(SEXP xSEXP);
@@ -95,17 +105,16 @@ SEXP Rfast_k_nn_cv(SEXP foldsSEXP,SEXP ySEXP,SEXP dsSEXP,SEXP idxsSEXP,SEXP dist
 SEXP Rfast_k_comb_n(SEXP nSEXP,SEXP kSEXP);
 SEXP Rfast_lowerbound(SEXP xSEXP,SEXP vSEXP);
 SEXP Rfast_Lgamma(SEXP x);
-SEXP Rfast_len_sort_unique_double(SEXP xSEXP);
 SEXP Rfast_len_sort_unique_int(SEXP xSEXP);
 SEXP Rfast_Log(SEXP x);
 SEXP Rfast_logistic_only(SEXP xSEXP,SEXP ySEXP,SEXP tolSEXP);
 SEXP Rfast_logistic_only_b(SEXP xSEXP,SEXP ySEXP,SEXP tolSEXP);
 SEXP Rfast_Lbeta(SEXP x,SEXP y);
 SEXP Rfast_lower_tri(SEXP xSEXP,SEXP dgSEXP);
+SEXP Rfast_lower_tri_assign(SEXP xSEXP,SEXP vSEXP,SEXP dgSEXP);
 SEXP Rfast_lower_tri_b(SEXP nclSEXP, SEXP nrwSEXP,SEXP dgSEXP);
 SEXP Rfast_Lchoose(SEXP x,SEXP kSEXP);
 SEXP Rfast_mahaCpp(SEXP X, SEXP mu, SEXP sigma, SEXP isChol);
-SEXP Rfast_matrix_sum(SEXP x);
 SEXP Rfast_min_freq_d(SEXP xSEXP,SEXP na_rmSEXP);
 SEXP Rfast_min_freq_i(SEXP xSEXP,SEXP na_rmSEXP);
 SEXP Rfast_max_freq_d(SEXP xSEXP,SEXP na_rmSEXP); 
@@ -116,12 +125,16 @@ SEXP Rfast_min_max(SEXP x,SEXP indexSEXP);
 SEXP Rfast_mat_mat(SEXP xSEXP,SEXP ySEXP);
 SEXP Rfast_med(SEXP x,SEXP na_rmSEXP);
 SEXP Rfast_min_max_perc(SEXP x);
+SEXP Rfast_negative(SEXP xSEXP,SEXP methodSEXP);
 SEXP Rfast_nth(SEXP xSEXP,SEXP ySEXP,SEXP descendSEXP,SEXP na_rmSEXP);
+SEXP Rfast_nth_int(SEXP xSEXP,SEXP elemSEXP);
 SEXP Rfast_nth_index(SEXP xSEXP,SEXP ySEXP,SEXP descendSEXP,SEXP na_rmSEXP);
 SEXP Rfast_Norm(SEXP xSEXP,SEXP typeSEXP);
 SEXP Rfast_Order(SEXP xSEXP,SEXP stableSEXP,SEXP descendSEXP);
 SEXP Rfast_odds_helper(SEXP x);
 SEXP Rfast_Outer(SEXP x,SEXP y,SEXP operSEXP);
+SEXP Rfast_positive(SEXP xSEXP,SEXP methodSEXP);
+SEXP Rfast_positive_negative(SEXP xSEXP,SEXP methodSEXP);
 SEXP Rfast_poisson_only(SEXP xSEXP,SEXP ySEXP,SEXP ylogySEXP,SEXP tolSEXP);
 SEXP Rfast_partial_sort(SEXP x,SEXP nSEXP,SEXP descendSEXP);
 SEXP Rfast_partial_sort_index(SEXP x,SEXP nSEXP,SEXP descendSEXP);
@@ -138,7 +151,8 @@ SEXP Rfast_permutation_prev(SEXP xSEXP,SEXP npermSEXP);
 SEXP Rfast_perm_cor(SEXP xSEXP,SEXP ySEXP,SEXP rSEXP);
 SEXP Rfast_qpois_reg(SEXP xSEXP,SEXP ySEXP,SEXP ylogySEXP,SEXP tolSEXP,SEXP maxitersSEXP);
 SEXP Rfast_qpois_regs(SEXP xSEXP,SEXP ySEXP,SEXP tolSEXP,SEXP ylogySEXP,SEXP mySEXP);
-SEXP Rfast_rank(SEXP xSEXP,SEXP methodSEXP,SEXP descendSEXP,SEXP stableSEXP);
+SEXP Rfast_rank(SEXP xSEXP,SEXP methodSEXP,SEXP descendSEXP);
+SEXP Rfast_remove_from_namespace(SEXP dir_to_exportSEXP,SEXP files_to_removeSEXP);
 SEXP Rfast_rbing(SEXP nSEXP,SEXP lamSEXP);
 SEXP Rfast_rows(SEXP x,SEXP ind);
 SEXP Rfast_row_any(SEXP xSEXP);
@@ -183,6 +197,7 @@ SEXP Rfast_symmetric(SEXP xSEXP);
 SEXP Rfast_Sort(SEXP x,SEXP descendSEXP,SEXP na);
 SEXP Rfast_Sort_na_first(SEXP xSEXP,SEXP descendSEXP);
 SEXP Rfast_sort_string(SEXP xSEXP,SEXP descendSEXP);
+SEXP Rfast_sort_int(SEXP xSEXP);
 SEXP Rfast_stable_sort(SEXP x,SEXP descendSEXP);
 SEXP Rfast_spat_med(SEXP xSEXP,SEXP tolSEXP);
 SEXP Rfast_squareform_c(SEXP xSEXP);
@@ -198,6 +213,7 @@ SEXP Rfast_table2_c(SEXP x,SEXP y,SEXP rm_zerosSEXP);
 SEXP Rfast_table2_with_names(SEXP x,SEXP y,SEXP rm_zerosSEXP);
 SEXP Rfast_transpose_sq(SEXP xSEXP);
 SEXP Rfast_upper_tri(SEXP xSEXP,SEXP dgSEXP);
+SEXP Rfast_upper_tri_assign(SEXP xSEXP,SEXP vSEXP,SEXP dgSEXP);
 SEXP Rfast_upper_tri_b(SEXP nclSEXP, SEXP nrwSEXP,SEXP dgSEXP);
 SEXP Rfast_var_c(SEXP xSEXP);
 SEXP Rfast_var_c_na_rm(SEXP xSEXP,SEXP na_rmSEXP);
@@ -208,6 +224,7 @@ SEXP Rfast_which_isFactor(SEXP xSEXP);
 SEXP Rfast_col_row_zero(SEXP xSEXP);
 
 SEXP Rfast_colrint_mle(SEXP XSEXP,SEXP idSEXP,SEXP ranefSEXP,SEXP tolSEXP,SEXP maxitersSEXP,SEXP parallelSEXP);
+SEXP Rfast_eigs_sym_c(SEXP XSEXP,SEXP kSEXP);
 SEXP Rfast_geom_regs(SEXP YSEXP,SEXP XSEXP,SEXP tolSEXP,SEXP loggedSEXP,SEXP typeSEXP,SEXP parallelSEXP,SEXP maxitersSEXP);
 SEXP Rfast_dir_knn(SEXP tXnewSEXP,SEXP tXSEXP,SEXP YSEXP,SEXP KSEXP,SEXP typeSEXP,SEXP parallelSEXP);
 SEXP Rfast_multinom_regs(SEXP Y0SEXP,SEXP X0SEXP,SEXP tolSEXP,SEXP loggedSEXP,SEXP maxitersSEXP);
@@ -234,6 +251,7 @@ SEXP Rfast_col_nth_p(SEXP xSEXP,SEXP ySEXP);
 SEXP Rfast_col_order_p(SEXP xSEXP,SEXP stableSEXP,SEXP descendingSEXP);
 SEXP Rfast_col_ranks_p(SEXP xSEXP,SEXP methodSEXP,SEXP descendSEXP,SEXP stableSEXP);
 SEXP Rfast_col_sums_p(SEXP xSEXP);
+SEXP Rfast_mat_mult_p(SEXP xSEXP,SEXP ySEXP);
 SEXP Rfast_row_all_p(SEXP xSEXP);
 SEXP Rfast_row_count_values_p(SEXP xSEXP,SEXP valuesSEXP);
 SEXP Rfast_row_mads_p(SEXP x);
@@ -244,9 +262,11 @@ SEXP Rfast_row_ranks_p(SEXP xSEXP,SEXP methodSEXP,SEXP descendSEXP,SEXP stableSE
 SEXP Rfast_row_sums_p(SEXP xSEXP);
 SEXP Rfast_stable_sort_mat_p(SEXP xSEXP,SEXP descendSEXP,SEXP by_rowSEXP);
 SEXP Rfast_sort_mat_p(SEXP xSEXP,SEXP descendSEXP,SEXP by_rowSEXP);
+SEXP Rfast_transpose_g_p(SEXP xSEXP);
 
 static const R_CallMethodDef CallEntries[] = {
-  {"Rfast_add_to_namespace", (DL_FUNC) &Rfast_add_to_namespace, 3},
+  {"Rfast_add_to_namespace", (DL_FUNC) &Rfast_add_to_namespace, 4},
+  {"Rfast_apply_condition", (DL_FUNC) &Rfast_apply_condition, 4},
   {"Rfast_as_integer", (DL_FUNC) &Rfast_as_integer, 3},
   {"Rfast_bcdcor", (DL_FUNC) &Rfast_bcdcor, 2},
   {"Rfast_binarysearch", (DL_FUNC) &Rfast_binarysearch, 2},
@@ -255,6 +275,10 @@ static const R_CallMethodDef CallEntries[] = {
   {"Rfast_bincomb", (DL_FUNC) &Rfast_bincomb, 1},
   {"Rfast_col_all", (DL_FUNC) &Rfast_col_all, 1},
   {"Rfast_col_count_values", (DL_FUNC) &Rfast_col_count_values, 2},
+  {"Rfast_col_cum_maxs", (DL_FUNC) &Rfast_col_cum_maxs, 1},
+  {"Rfast_col_cum_sums", (DL_FUNC) &Rfast_col_cum_sums, 1},
+  {"Rfast_col_cum_mins", (DL_FUNC) &Rfast_col_cum_mins, 1},
+  {"Rfast_col_cum_prods", (DL_FUNC) &Rfast_col_cum_prods, 1},
   {"Rfast_col_meds", (DL_FUNC) &Rfast_col_meds, 2},
   {"Rfast_col_min_indices", (DL_FUNC) &Rfast_col_min_indices, 1},
   {"Rfast_col_min", (DL_FUNC) &Rfast_col_min, 1},
@@ -274,11 +298,15 @@ static const R_CallMethodDef CallEntries[] = {
   {"Rfast_col_order", (DL_FUNC) &Rfast_col_order, 3},
   {"Rfast_col_pmax", (DL_FUNC) &Rfast_col_pmax, 2},
   {"Rfast_col_pmin", (DL_FUNC) &Rfast_col_pmin, 2},
-  {"Rfast_col_prods", (DL_FUNC) &Rfast_col_prods, 1},
+  {"Rfast_col_prods", (DL_FUNC) &Rfast_col_prods, 2},
   {"Rfast_columns", (DL_FUNC) &Rfast_columns, 2},
+  {"Rfast_chi2Test_univariate", (DL_FUNC) &Rfast_chi2Test_univariate, 2},
+  {"Rfast_chi2Test", (DL_FUNC) &Rfast_chi2Test, 5},
+  {"Rfast_chi2tests", (DL_FUNC) &Rfast_chi2tests, 4},
   {"Rfast_check_namespace", (DL_FUNC) &Rfast_check_namespace, 2},
   {"Rfast_check_aliases", (DL_FUNC) &Rfast_check_aliases, 3},
   {"Rfast_check_true_false", (DL_FUNC) &Rfast_check_true_false, 2},
+  {"Rfast_check_usage", (DL_FUNC) &Rfast_check_usage, 3},
   {"Rfast_col_any", (DL_FUNC) &Rfast_col_any, 1},
   {"Rfast_col_anovas", (DL_FUNC) &Rfast_col_anovas, 2},
   {"Rfast_cholesky", (DL_FUNC) &Rfast_cholesky, 1},
@@ -286,7 +314,6 @@ static const R_CallMethodDef CallEntries[] = {
   {"Rfast_col_mads", (DL_FUNC) &Rfast_col_mads, 1},
   {"Rfast_col_true_false", (DL_FUNC) &Rfast_col_true_false, 1},
   {"Rfast_count_value", (DL_FUNC) &Rfast_count_value, 2},
-  {"Rfast_count_na", (DL_FUNC) &Rfast_count_na, 1},
   {"Rfast_Choose", (DL_FUNC) &Rfast_Choose, 2},
   {"Rfast_dvar", (DL_FUNC) &Rfast_dvar, 1},
   {"Rfast_dcor", (DL_FUNC) &Rfast_dcor, 2},
@@ -331,22 +358,22 @@ static const R_CallMethodDef CallEntries[] = {
   {"Rfast_hash2list", (DL_FUNC) &Rfast_hash2list, 2},
   {"Rfast_hash_find", (DL_FUNC) &Rfast_hash_find, 2},
   {"Rfast_Hash_list", (DL_FUNC) &Rfast_Hash_list, 2},
+  {"Rfast_Hash_key_multi", (DL_FUNC) &Rfast_Hash_key_multi, 3},
   {"Rfast_is_element", (DL_FUNC) &Rfast_is_element, 2},
   {"Rfast_is_element_string", (DL_FUNC) &Rfast_is_element_string, 2},
   {"Rfast_is_integer", (DL_FUNC) &Rfast_is_integer, 1},
   {"Rfast_k_nn", (DL_FUNC) &Rfast_k_nn, 9},
   {"Rfast_k_nn_cv", (DL_FUNC) &Rfast_k_nn_cv, 10},
   {"Rfast_k_comb_n", (DL_FUNC) &Rfast_k_comb_n, 2},
-  /*{"Rfast_kron", (DL_FUNC) &Rfast_kron, 2},*/
   {"Rfast_lowerbound", (DL_FUNC) &Rfast_lowerbound, 2},
   {"Rfast_Lgamma", (DL_FUNC) &Rfast_Lgamma, 1},
-  {"Rfast_len_sort_unique_double", (DL_FUNC) &Rfast_len_sort_unique_double, 1},
   {"Rfast_len_sort_unique_int", (DL_FUNC) &Rfast_len_sort_unique_int, 1},
   {"Rfast_Log", (DL_FUNC) &Rfast_Log, 1},
   {"Rfast_logistic_only_b", (DL_FUNC) &Rfast_logistic_only_b, 3},
   {"Rfast_logistic_only", (DL_FUNC) &Rfast_logistic_only, 3},
   {"Rfast_Lbeta", (DL_FUNC) &Rfast_Lbeta, 2},
   {"Rfast_lower_tri", (DL_FUNC) &Rfast_lower_tri, 2},
+  {"Rfast_lower_tri_assign", (DL_FUNC) &Rfast_lower_tri_assign, 3},
   {"Rfast_lower_tri_b", (DL_FUNC) &Rfast_lower_tri_b, 3},
   {"Rfast_Lchoose", (DL_FUNC) &Rfast_Lchoose, 2},
   {"Rfast_mahaCpp", (DL_FUNC) &Rfast_mahaCpp, 4},
@@ -354,19 +381,22 @@ static const R_CallMethodDef CallEntries[] = {
   {"Rfast_min_freq_i", (DL_FUNC) &Rfast_min_freq_i, 2},
   {"Rfast_max_freq_d", (DL_FUNC) &Rfast_max_freq_d, 2},
   {"Rfast_max_freq_i", (DL_FUNC) &Rfast_max_freq_i, 2},
-  {"Rfast_matrix_sum", (DL_FUNC) &Rfast_matrix_sum, 1},
   {"Rfast_Match", (DL_FUNC) &Rfast_Match, 2},
   {"Rfast_mad2", (DL_FUNC) &Rfast_mad2, 3},
   {"Rfast_min_max", (DL_FUNC) &Rfast_min_max, 2},
   {"Rfast_mat_mat", (DL_FUNC) &Rfast_mat_mat, 2},
   {"Rfast_med", (DL_FUNC) &Rfast_med, 2},
   {"Rfast_min_max_perc", (DL_FUNC) &Rfast_min_max_perc, 1},
+  {"Rfast_negative", (DL_FUNC) &Rfast_negative, 2},
   {"Rfast_nth", (DL_FUNC) &Rfast_nth, 4},
+  {"Rfast_nth_int", (DL_FUNC) &Rfast_nth_int, 2},
   {"Rfast_nth_index", (DL_FUNC) &Rfast_nth_index, 4},
   {"Rfast_Norm", (DL_FUNC) &Rfast_Norm, 2},
   {"Rfast_Order", (DL_FUNC) &Rfast_Order, 3},
-  {"Rfast_Outer", (DL_FUNC) &Rfast_Outer, 2},
+  {"Rfast_Outer", (DL_FUNC) &Rfast_Outer, 3},
   {"Rfast_odds_helper", (DL_FUNC) &Rfast_odds_helper, 1},
+  {"Rfast_positive", (DL_FUNC) &Rfast_positive, 2},
+  {"Rfast_positive_negative", (DL_FUNC) &Rfast_positive_negative, 2},
   {"Rfast_poisson_only", (DL_FUNC) &Rfast_poisson_only, 4},
   {"Rfast_partial_sort", (DL_FUNC) &Rfast_partial_sort, 3},
   {"Rfast_partial_sort_index", (DL_FUNC) &Rfast_partial_sort_index, 3},
@@ -383,7 +413,8 @@ static const R_CallMethodDef CallEntries[] = {
   {"Rfast_perm_cor", (DL_FUNC) &Rfast_perm_cor, 3},
   {"Rfast_qpois_reg", (DL_FUNC) &Rfast_qpois_reg, 5},
   {"Rfast_qpois_regs", (DL_FUNC) &Rfast_qpois_regs, 5},
-  {"Rfast_rank", (DL_FUNC) &Rfast_rank, 4},
+  {"Rfast_rank", (DL_FUNC) &Rfast_rank, 3},
+  {"Rfast_remove_from_namespace", (DL_FUNC) &Rfast_remove_from_namespace, 2},
   {"Rfast_rbing", (DL_FUNC) &Rfast_rbing, 2},
   {"Rfast_rows", (DL_FUNC) &Rfast_rows, 2},
   {"Rfast_row_count_values", (DL_FUNC) &Rfast_row_count_values, 2},
@@ -429,6 +460,7 @@ static const R_CallMethodDef CallEntries[] = {
   {"Rfast_Sort_na_first", (DL_FUNC) &Rfast_Sort_na_first, 3},
   {"Rfast_sort_string", (DL_FUNC) &Rfast_sort_string, 2},
   {"Rfast_stable_sort", (DL_FUNC) &Rfast_stable_sort, 2},
+  {"Rfast_sort_int", (DL_FUNC) &Rfast_sort_int, 1},
   {"Rfast_spat_med", (DL_FUNC) &Rfast_spat_med, 2},
   {"Rfast_squareform_c", (DL_FUNC) &Rfast_squareform_c, 1},
   {"Rfast_spml_reg_helper", (DL_FUNC) &Rfast_spml_reg_helper, 8},
@@ -442,7 +474,9 @@ static const R_CallMethodDef CallEntries[] = {
   {"Rfast_table2_c", (DL_FUNC) &Rfast_table2_c, 3},
   {"Rfast_table2_with_names", (DL_FUNC) &Rfast_table2_with_names, 3},
   {"Rfast_transpose_sq", (DL_FUNC) &Rfast_transpose_sq, 1},
+  {"Rfast_transpose_g_p", (DL_FUNC) &Rfast_transpose_g_p, 1},
   {"Rfast_upper_tri", (DL_FUNC) &Rfast_upper_tri, 2},
+  {"Rfast_upper_tri_assign", (DL_FUNC) &Rfast_upper_tri_assign, 3},
   {"Rfast_upper_tri_b", (DL_FUNC) &Rfast_upper_tri_b, 3},
   {"Rfast_var_c", (DL_FUNC) &Rfast_var_c, 1},
   {"Rfast_var_c_na_rm", (DL_FUNC) &Rfast_var_c_na_rm, 2},
@@ -464,6 +498,7 @@ static const R_CallMethodDef CallEntries[] = {
   {"Rfast_col_ranks_p", (DL_FUNC) &Rfast_col_ranks_p, 4},
   {"Rfast_col_sums_p", (DL_FUNC) &Rfast_col_sums_p, 1},
   {"Rfast_col_order_p", (DL_FUNC) &Rfast_col_order_p, 3},
+  {"Rfast_mat_mult_p", (DL_FUNC) &Rfast_mat_mult_p, 2},
   {"Rfast_row_all_p", (DL_FUNC) &Rfast_row_all_p, 1},
   {"Rfast_row_count_values_p", (DL_FUNC) &Rfast_row_count_values_p, 2},
   {"Rfast_row_mads_p", (DL_FUNC) &Rfast_row_mads_p, 1},
@@ -476,6 +511,7 @@ static const R_CallMethodDef CallEntries[] = {
   {"Rfast_sort_mat_p", (DL_FUNC) &Rfast_sort_mat_p, 3},
 
   {"Rfast_colrint_mle", (DL_FUNC) &Rfast_colrint_mle, 6},
+  {"Rfast_eigs_sym_c", (DL_FUNC) &Rfast_eigs_sym_c, 2},
   {"Rfast_geom_regs", (DL_FUNC) &Rfast_geom_regs, 7},
   {"Rfast_normlog_regs", (DL_FUNC) &Rfast_normlog_regs, 8},
   {"Rfast_dir_knn", (DL_FUNC) &Rfast_dir_knn, 6},
