@@ -30,34 +30,28 @@ vec* removeVecIdx(int, vec *, int);
 double glm_logistic3(mat, vec,const double,double,int);
 double glm_poisson_3(mat, vec, const double,const double,int);
 double prop_reg3(mat, vec, const double, double,int);
-vec group_sum2(vec, NumericVector, const int);
-vec group_sum3(vec, vec,const int);
 double calc_f(vec, double, vec, double, double, int);
-mat design_matrix2(vec,bool);
-mat cross_x_2(mat);
-mat cross_x_y_2(mat,mat);
 mat create_id_mat(int);
 double calc_multinom_ini(mat,vec);
 vec indexesOfNum(mat,int);
 double sumabsmat(mat,mat,int);
 double calcSumLog(mat,vec,int);
 vector<double> sort_unique_double(vector<double>);
-mat design_matrix2(CharacterVector,bool);
 mat colvec_mat_cbind(vec, mat);
 double calcDevRes(mat,vec,mat);
 vec gold_rat3(double, vec, vec, double, vec, const int, const double);
-double rint_reg2(mat, vec, vec,vec,const int, const double,int);
-vec rint_regs2(mat, vec, vec, vec, const double, int,int);
+double rint_reg2(mat, vec, vec, IntegerVector, int, const double,int);
+vec rint_regs2(mat, vec, vec, IntegerVector, const double, int,int);
 double qpois_reg2(mat, vec,const double,const double,int);
 List varcomps_mle(NumericVector,IntegerVector,const int,const double);
-double varcomps_mle2(vec, vec,const int,const double);
-double rint_mle2(vec, vec, vec, const double, int);
-double bic_rint_reg(mat, vec, vec, vec, const int, const double, int);
-vec bic_rint_regs(mat, vec, vec, vec, const double, int, int);
+double varcomps_mle2(vec, IntegerVector,int,const double);
+double rint_mle2(vec, vec, IntegerVector, const double, int);
+double bic_rint_reg(mat, vec, vec, IntegerVector, const int, const double, int);
+vec bic_rint_regs(mat, vec, vec, IntegerVector, const double, int, int);
 List glm_poisson_2(mat, vec, const double,const double, const int);
 vec my_pow2(vec,vec,const double,const int);
 vec weibull_mle2(vec, int, const double, const int);
-mat varcomps_mle3(vec, vec,const int, const int,const bool, const double,const int);
+mat varcomps_mle3(vec, IntegerVector,const int, int,const bool, const double,const int);
 double spml_mle2(mat, vec, vec, vec, const int, const double, const int);
 
 #endif
